#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-splice-plugin
version:              2.3.0.0
visibility:           public
id:                   hls-splice-plugin-2.3.0.0-Lgoj5ZAJkxb8hhNWOjlUZ0
key:                  hls-splice-plugin-2.3.0.0-Lgoj5ZAJkxb8hhNWOjlUZ0
license:              Apache-2.0
maintainer:
    https://github.com/haskell/haskell-language-server/contributors

author:
    https://github.com/haskell/haskell-language-server/contributors

synopsis:
    HLS Plugin to expand TemplateHaskell Splices and QuasiQuotes

description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  393a064cdb6e14a41ed9fb86194f7237
exposed:              True
exposed-modules:      Ide.Plugin.Splice Ide.Plugin.Splice.Types
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hls-splice-plugin-2.3.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hls-splice-plugin-2.3.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hls-splice-plugin-2.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-splice-plugin
hs-libraries:         HShls-splice-plugin-2.3.0.0-Lgoj5ZAJkxb8hhNWOjlUZ0
depends:
    aeson-2.2.2.0-Bvq1RZLTB982HJyF7e96XU base-4.18.2.1 containers-0.6.7
    dlist-1.0-B7D1vsARFiIHVaGk5CGbYO
    extra-1.7.16-EBdVSHGIn1MFifI9eiYLtn
    foldl-1.4.18-1StBBU5EZsYGde29thr1xc ghc-9.6.6
    ghc-exactprint-1.7.1.0-1tvX3UuZ7ReIr5GtVrBS0b
    ghcide-2.3.0.0-Hbv2cBdOZ4wF1P08d9kiL2
    hls-plugin-api-2.3.0.0-CFYA2x6DkFk6nkZ81oKeX3
    hls-refactor-plugin-2.3.0.0-CsR4tSkF39XGr2qoGq8BTD
    lens-5.3.4-4VhpdbpDp0x9CLN9dxQmc7
    lsp-2.2.0.0-9l0Xn8RQH2K7GgMCagaeTr mtl-2.3.1
    retrie-1.2.3-4cKfFwjWI6K8of7j0GSDAA
    syb-0.7.3-AsxB5kY1s6JBFiF2Kn9gZL text-2.0.2 transformers-0.6.1.0
    unliftio-core-0.2.1.0-6sOpIonHj8t5wIbPhWbPHY
    unordered-containers-0.2.20.1-ITIVaOGw28dDFkmcPJu0s3

haddock-interfaces:
    /usr/share/doc/haskell-hls-splice-plugin/html/hls-splice-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-splice-plugin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

